@@ -25,40 +25,43 @@
 #' library(sf)
 #'
 #' brno <- obce_polygony() %>% # shapefile of Brno
-#'    filter(NAZ_OBEC == "Brno")
+#'   filter(NAZ_OBEC == "Brno") %>%
+#'   st_set_crs(5514) %>% # a planar CRS
+#'   st_set_agr("constant") # to avoid raising a warning
 #'
 #' pupek_brna <- st_centroid(brno) # calculate centroid
 #'
 #' adresa_pupku <- revgeo(pupek_brna)$revgeocoded # address of the center
-#'
 #' @export
 #' @importFrom magrittr %>%
 #'
 
 
 revgeo <- function(coords) {
-
   network <- as.logical(Sys.getenv("NETWORK_UP", unset = TRUE)) # dummy variable to allow testing of network
 
   if (missing(coords)) stop("required argument coords is missing")
 
   if (!inherits(coords, "sf")) stop("coords is expected in sf format")
 
-  if (sf::st_geometry_type(coords)[1] != 'POINT') stop("reverse geocoding is limited to sf point objects")
+  if (sf::st_geometry_type(coords)[1] != "POINT") stop("reverse geocoding is limited to sf point objects")
 
   coords$revgeocoded <- NULL # initiate result column in coords data frame
 
   coords_krovak <- sf::st_transform(coords, crs = 5514) # a temporary version of coords, in a very specific CRS
 
   # coordinates as a string understood by CUZK API
-  coords_krovak$modified <- paste0(sf::st_coordinates(coords_krovak)[,"X"],
-                            ",",
-                            sf::st_coordinates(coords_krovak)[,"Y"])
+  coords_krovak$modified <- paste0(
+    sf::st_coordinates(coords_krovak)[, "X"],
+    ",",
+    sf::st_coordinates(coords_krovak)[, "Y"]
+  )
 
   for (i in seq_along(coords_krovak$modified)) {
-
-    query <- paste0("http://ags.cuzk.cz/arcgis/rest/services/RUIAN/Vyhledavaci_sluzba_nad_daty_RUIAN/MapServer/exts/GeocodeSOE/tables/1/reverseGeocode",
-              "?location=", coords_krovak$modified[i], "&f=pjson")
+    query <- paste0(
+      "http://ags.cuzk.cz/arcgis/rest/services/RUIAN/Vyhledavaci_sluzba_nad_daty_RUIAN/MapServer/exts/GeocodeSOE/tables/1/reverseGeocode",
+      "?location=", coords_krovak$modified[i], "&f=pjson"
+    )
 
     resp <- httr::GET(query)
 
@@ -78,7 +81,6 @@ revgeo <- function(coords) {
 
     # update the value in coords data frame
     coords$revgeocoded[i] <- adresa["Address"]$Address
-
   } # /for
 
 
